@@ -142,7 +142,8 @@ tbl_continuous <- function(data,
     dplyr::bind_rows(
       cards,
       cards::ard_attributes(data, variables = all_of(c(variable, by, include)), label = label),
-      cards::ard_categorical(data, variables = any_of(by), stat_label = ~ default_stat_labels())
+      cards::ard_categorical(data, variables = any_of(by), stat_label = ~ default_stat_labels()),
+      cards::ard_total_n(data)
     )
 
   # fill NULL stats with NA
@@ -160,13 +161,6 @@ tbl_continuous <- function(data,
   # prepare the base table via `brdg_continuous()` -----------------------------
   x <- brdg_continuous(cards, by = by, statistic = statistic, include = include, variable = variable)
 
-  # if no by variable, fix the header N ----------------------------------------
-  if (is_empty(by)) {
-    x$table_styling$header <- x$table_styling$header |>
-      dplyr::mutate(across(c("modify_stat_N", "modify_stat_n"), ~nrow(data)))
-  }
-
-
   # adding styling -------------------------------------------------------------
   x <- x |>
     # updating the headers for the stats columns
