@@ -1,17 +1,18 @@
 #' @title Methods for tbl_regression
 #'
-#' @description Most regression models are handled by [tbl_regression.default()],
-#' which uses [broom::tidy()] to perform initial tidying of results. There are,
+#' @description Most regression models are handled by [`tbl_regression()`],
+#' which uses [`broom::tidy()`] to perform initial tidying of results. There are,
 #' however, some model types that have modified default printing behavior.
 #' Those methods are listed below.
 #'
-#' @inheritSection tbl_regression Methods
-#' @name tbl_regression_methods
-#' @keywords internal
-#' @rdname tbl_regression_methods
-#' @param ... arguments passed to `tbl_regression.default()`
+#' @param ... arguments passed to `tbl_regression()`
 #' @inheritParams tbl_regression
 #' @inheritParams tbl_stack
+#'
+#' @name tbl_regression_methods
+#' @keywords internal
+#'
+#' @inheritSection tbl_regression Methods
 NULL
 
 #' @export
@@ -24,31 +25,22 @@ tbl_regression.model_fit <- function(x, ...) {
 #' @export
 #' @rdname tbl_regression_methods
 tbl_regression.workflow <- function(x, ...) {
-  assert_package("workflows", "tbl_regression.workflow()")
+  check_pkg_installed("workflows", reference_pkg = "gtsummary")
 
   if (isTRUE(!x$pre$actions$formula$blueprint$indicators %in% "none")) {
-    paste(
-      "To take full advantage of model formatting, e.g. grouping categorical",
-      "variables, please add the following argument to the `workflows::add_model()` call:"
-    ) %>%
-      stringr::str_wrap() %>%
-      paste("`blueprint = hardhat::default_formula_blueprint(indicators = 'none')`", sep = "\n") %>%
-      paste("\n") %>%
-      rlang::inform()
+    cli::cli_inform(
+      c( i = "To take full advantage of model formatting, e.g. grouping categorical
+      variables, please add the following argument to the {.fun workflows::add_model} call:",
+        "*" = "{.code blueprint = hardhat::default_formula_blueprint(indicators = 'none')}")
+    )
   }
 
-  paste(
-    "Extracting {workflows} model fit with",
-    "`workflows::extract_fit_parsnip(x) %>% tbl_regression(...)`"
-  ) %>%
-    message()
-
   tbl_regression(x = workflows::extract_fit_parsnip(x), ...)
 }
 
 #' @export
 #' @rdname tbl_regression_methods
-tbl_regression.survreg <- function(x, tidy_fun = function(x, ...) broom::tidy(x, ...) %>% dplyr::filter(.data$term != "Log(scale)"), ...) {
+tbl_regression.survreg <- function(x, tidy_fun = function(x, ...) broom::tidy(x, ...) |> dplyr::filter(.data$term != "Log(scale)"), ...) {
   tbl_regression.default(x = x, tidy_fun = tidy_fun, ...)
 }
 
@@ -68,26 +60,19 @@ tbl_regression.mira <- function(x, tidy_fun = pool_and_tidy_mice, ...) {
 #' @export
 #' @rdname tbl_regression_methods
 tbl_regression.mipo <- function(x, ...) {
-  paste(
-    "Please pass the 'mice' model to {.code tbl_regression()} before ",
-    "models have been combined with {.code mice::pool()}.",
-    "The default tidier, {.code pool_and_tidy_mice()}, ", "
-        will both pool and tidy the regression model."
-  ) %>%
-    stringr::str_wrap() %>%
-    cli_alert_danger()
-  paste("\n\nmice::mice(trial, m = 2) %>%",
-    "with(lm(age ~ marker + grade)) %>%",
-    "tbl_regression()",
-    sep = "\n  "
-  ) %>%
-    cli_code()
+  cli::cli_inform(
+    c("i" = "Pass the {.cls mice} model to {.code tbl_regression()} before
+             models have been combined with {.fun mice::pool}.",
+       "*" = "The default tidier, {.fun pool_and_tidy_mice},
+              will both pool and tidy the regression model.",
+      "*" = "{.run mice::mice(trial, m = 2) |> with(lm(age ~ marker + grade)) |> tbl_regression()}")
+  )
 }
 
 #' @export
 #' @rdname tbl_regression_methods
-tbl_regression.lmerMod <- function(x, tidy_fun = function(x, ...) broom.mixed::tidy(x, ..., effects = "fixed"), ...) {
-  assert_package("broom.mixed", "tbl_regression.lmerMod()")
+tbl_regression.lmerMod <- function(x, tidy_fun = \(x, ...) broom.mixed::tidy(x, ..., effects = "fixed"), ...) {
+  check_pkg_installed("broom.mixed", reference_pkg = "gtsummary")
   tbl_regression.default(x = x, tidy_fun = tidy_fun, ...)
 }
 
@@ -117,18 +102,14 @@ tbl_regression.gam <- function(x, tidy_fun = tidy_gam, ...) {
   tbl_regression.default(x = x, tidy_fun = tidy_fun, ...)
 }
 
-#' @export
-#' @rdname tbl_regression_methods
-tbl_regression.tidycrr <- function(x, tidy_fun = tidycmprsk::tidy, ...) {
-  assert_package("tidycmprsk", "tbl_regression.tidycrr()")
-  tbl_regression.default(x = x, tidy_fun = tidy_fun, ...)
-}
-
 #' @export
 #' @rdname tbl_regression_methods
 tbl_regression.crr <- function(x, ...) {
-  cli::cli_alert_info("For better summary support, build model with {.code tidycmprsk::crr()}.")
-  cli::cli_ul("Visit {.url https://mskcc-epi-bio.github.io/tidycmprsk/} for details.")
+  cli::cli_inform(
+    c("For better summary support, build model with {.fun tidycmprsk::crr}.",
+      "Visit {.url https://mskcc-epi-bio.github.io/tidycmprsk/} for details.")
+  )
+
   tbl_regression.default(x = x, ...)
 }
 
@@ -144,10 +125,10 @@ tbl_regression.multinom <- function(x, ...) {
 .multinom_modifations <- function(x) {
   # adding a grouped header for the outcome levels
   x$table_body <-
-    x$table_body %>%
-    mutate(groupname_col = .data$y.level, .before = 1)
-  x <-
-    modify_table_styling(
+    x$table_body |>
+    mutate(groupname_col = .data$y.level, .before = 1L)
+
+  x <- modify_table_styling(
       x = x,
       columns = all_of("groupname_col"),
       hide = FALSE,
@@ -156,15 +137,11 @@ tbl_regression.multinom <- function(x, ...) {
     )
 
   # warning about multinomial models
-  paste(
-    "Multinomial models have a different underlying structure than",
-    "the models gtsummary was designed for.",
-    "Other gtsummary functions designed to work with",
-    "{.field tbl_regression} objects may yield unexpected",
-    "results."
-  ) %>%
-    str_wrap() %>%
-    cli_alert_info()
+  cli::cli_inform(
+    c("i" = "Multinomial models have a different underlying structure than the
+             models gtsummary was designed for.",
+      "*" = "Functions designed to work with {.fun tbl_regression} objects may yield unexpected results.")
+  )
 
   x
 }
